##  Relevant Use Cases
This guide provides you with a clear best practice on how to model SAP solutions. It is key to look at the use case that you want to realize to decide which elements you want to focus on for architectural insights, such as fact sheet types, the number of hierarchy levels, and the attributes of fact sheet types ("backward thinking" principle as described in the [General Modeling Guidelines](https://help.sap.com/docs/leanix/ea/general-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how the SAP LeanIX meta model works and how to interpret key concepts like fact sheet attributes, tags, hierarchies, parent-child relations, and others.")). Below are some high-level recommendations for common SAP-related use cases; follow the provided links for detailed information on elements that are relevant for the respective use case:
Use Case | Insights From the SAP LeanIX Best Practice Model Approach
---|---
[Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") - Efficiently capture the SAP segment of your existing application portfolio in a standardized manner:
  * Model SAP systems as level 1 and 2 applications.
  * Link them to business capabilities and organization fact sheets.
  * Capture TIME attributes to assess your portfolio and identify application rationalization opportunities—especially useful in the context of ERP transformation.

|  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275021387a441014a39092f144fcb288_LowRes.png) . ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2751434e7a44101497928e7febe91736_LowRes.png)
[ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation?locale=en-US&state=PRODUCTION&version=CLOUD "Step-by-step guide for ERP Transformation using SAP LeanIX.") - Capture the as-is SAP ERP architecture, model the to-be architecture, and support the entire S4/HANA transformation:
  * Provide more business-relevant information by modeling objectives, business context, and platforms.
  * Add IT components, interfaces, and data objects to understand your integration architecture.
  * Model initiatives by defining their impacts with transformation items to create roadmaps, plan scenarios, and carry out the aligned roll-out plan and architectural changes.

The SAP LeanIX Architecture and Road Map Planning offers advanced capabilities for future-state architecture and scenario planning. To learn more, see [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management."). |  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27461e137a441014b3dbea3c498d658b_LowRes.png) . ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754d62d7a44101495bba670c8dc2587_LowRes.png) . ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756065c7a4410149867c54fbf7894c9_LowRes.png)
[Technology Risk Management](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of SAP LeanIX Technology Risk and Compliance, with links to detailed guides for managing obsolescence risk, optimizing technology usage, and enforcing tech standards across your IT landscape.") - Manage obsolescence risks, technology standards, etc., for your organization’s SAP assets. You can use the obsolescence risk view to prioritize which SAP applications are to be analyzed and evaluated for potential risks. Use surveys to validate data and determine whether application owners accept certain risks at the IT component level or if a transformation action is needed. |  ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2744ca4c7a441014aa7bd466d47a0448_LowRes.png)


